@@ -110,7 +110,7 @@ extern "C" int ctrl_c_interrupted(int exception);
 extern "C" void console_print(const char * s);
 extern "C" const char * console_prompt(const char * s);
 
-bool dfu_get_scriptstore_addr(size_t & start,size_t & taille);
+bool dfu_get_scriptstore_addr(size_t & start,size_t & taille,char & altdfu);
 bool dfu_get_scriptstore(const char * fname);
 bool dfu_send_scriptstore(const char * fname);
 bool dfu_send_rescue(const char * fname);
@@ -119,6 +119,7 @@ const int nwstoresize1=0x8000,nwstoresize2=0x8014;
 // send to 0x90000000+offset*0x10000
 bool dfu_send_firmware(const char * fname,int offset);
 bool dfu_send_apps(const char * fname);
+bool dfu_send_slotab(const char * fnamea,const char * fnameb1,const char * fnameb2);
 bool dfu_update_khicas(const char * fname); 
 
 #if defined HAVE_LIBMICROPYTHON
@@ -378,6 +379,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   extern int DEFAULT_EVAL_LEVEL;
   extern int PARENTHESIS_NWAIT;
   extern int MAX_PROD_EXPAND_SIZE;
+  extern int MAX_SIMPLIFIER_VECTSIZE;
 
   extern int TEST_PROBAB_PRIME; // probabilistic primality tests
   extern int GCDHEU_MAXTRY; // maximal number of retry for heuristic algorithms
@@ -396,6 +398,9 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   // Should be lower for larger coeff
   extern int MAX_ALG_EXT_ORDER_SIZE; // x^1/d extension not algebraic if d>
   extern int MAX_COMMON_ALG_EXT_ORDER_SIZE;
+  extern int LAZY_ALG_EXT;
+  extern int ALG_EXT_DIGITS;
+  // 0 use a unique algebraic extension, >0: don't search a unique alg ext if degree is >
   extern int TRY_FU_UPRIME;
   extern int SOLVER_MAX_ITERATE;
   extern int MAX_PRINTABLE_ZINT;
@@ -403,6 +408,9 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   extern int GBASIS_DETERMINISTIC;
   extern int GBASISF4_MAX_TOTALDEG;
   extern int GBASISF4_MAXITER;
+  extern int GBASIS_COEFF_STRATEGY;
+  extern float GBASIS_COEFF_MAXLOGRATIO;
+  extern int RUR_PARAM_MAX_DEG;
   // extern int GBASISF4_BUCHBERGER;
   extern unsigned max_pairs_by_iteration; 
   extern unsigned simult_primes,simult_primes2,simult_primes_seuil2,simult_primes3,simult_primes_seuil3; 
@@ -426,6 +434,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
 #endif
   extern double powlog2float;
   extern int MPZ_MAXLOG2;
+  extern int SET_COMPARE_MAXIDNT;
 
 #ifdef WITH_MYOSTREAM
   // replacement for std::cerr
@@ -647,7 +656,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
   };
   std::string gen2string(const gen & g);
   const int turtle_length=10;
-#ifdef KHICAS
+#if defined KHICAS || defined SDL_KHICAS
   struct logo_turtle {
     double x,y;
     double theta; // theta is given in degrees or radians dep. on angle_mode
@@ -662,7 +671,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
     // <0 fill a polygon from previous turtle positions
     logo_turtle(): x(100),y(100),theta(0),visible(true),mark(true),direct(true),color(0),turtle_width(1),radius(0) {}
     inline bool equal_except_nomark(const logo_turtle &t) const {
-      return x==t.x && y==t.y && turtle_width==t.turtle_width && s==t.s && radius==t.radius;
+      return x==t.x && y==t.y && turtle_width==t.turtle_width && s==t.s && radius==t.radius && visible==t.visible;;
     }
   };
 #else // KHICAS
@@ -779,7 +788,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
     std::string _autosimplify_;
     std::string _lastprog_name_;
     const char * _currently_scanned_;
-#ifndef KHICAS
+#if !defined KHICAS && !defined SDL_KHICAS
     std::vector<logo_turtle> _turtle_stack_; 
 #endif
     double _total_time_;
@@ -829,7 +838,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
   extern pthread_mutex_t context_list_mutex;
 #endif
   
-#if !defined(RTOS_THREADX) && !defined(BESTA_OS) && !defined(NSPIRE) && !defined(FXCG) && !defined KHICAS
+#if !defined(RTOS_THREADX) && !defined(BESTA_OS) && !defined(NSPIRE) && !defined(FXCG) && !defined KHICAS && !defined SDL_KHICAS
   extern std::map<std::string,context *> * context_names ;
 #endif
 
@@ -968,7 +977,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
   std::string lastprog_name(GIAC_CONTEXT);
   std::string lastprog_name(const std::string & b,GIAC_CONTEXT);
 
-#ifdef KHICAS
+#if defined KHICAS || defined SDL_KHICAS
   logo_turtle & turtle();
   std::vector<logo_turtle> & turtle_stack();
 #else
